#!/bin/sh
# http://re2c.sourceforge.net/
# script:  til (rob.til.freedman~AT~gmail.com)
set -e -u -x

CWD=$(pwd)
TMP=$CWD

NAME=re2c
VERSION=0.13.5
BUILD=${BUILD:-'54.1'}
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}

PKGNAME=$NAME-$VERSION
PACKAGE=$PKGNAME-$ARCH-$BUILD

# remove old dirs
[ -d $TMP/$PACKAGE ] && rm -fr $TMP/$PACKAGE
[ -d $TMP/$PKGNAME ] && rm -fr $TMP/$PKGNAME

# build dirs
PKG=$TMP/$PACKAGE
mkdir -p $PKG/install
mkdir -p $PKG/usr/{doc,src}/$PKGNAME

SOURCE=http://heanet.dl.sourceforge.net/sourceforge/$NAME/$PKGNAME.tar.gz
if [ ! -f $PKGNAME.tar.gz ]; then
    wget $SOURCE
fi

tar xzf $CWD/$PKGNAME.tar.gz -C $TMP || exit 1
cd $TMP/$PKGNAME

#export CFLAGS="-O3 -march=i686 -pipe -fomit-frame-pointer"

export CFLAGS="-O2 -march=i486 -mtune=i686"
export CXXFLAGS=$CFLAGS

./configure \
    --prefix=/usr \
    --mandir=/usr/man

make || exit 1
# recreate scanner.cc
rm scanner.cc

# makes sure, just compiled re2c is found first when recreating scanner.cc
# and *not* an installed re2c when running as root - i.e. '.' *not* included in path
PATH=.:$PATH make || exit 1

# make test already calls ./re2c
make test || exit 1
make install DESTDIR=$PKG || exit 1

# copy docs
cp CHANGELOG README  $PKG/usr/doc/$PKGNAME

# we just don't care
rm -fr lessons/001_upn_calculator/windows/

# if you're in need, unpack in privat space
tar czf $PKG/usr/doc/$PKGNAME/re2c_docs.tar.gz doc/* lessons/ htdocs/manual.html

# zip man page
gzip -9 $PKG/usr/man/man?/*.? 2> /dev/null

# strip symbols
strip --strip-unneeded $PKG/usr/bin/re2c

# Create the /install directory
#   |-----handy-ruler------------------------------------------------------|
echo "re2c: re2c (regular expression C code generator)
re2c:
re2c: re2c is a preprocessor that generates C-based recognizers from
re2c: regular expressions. The input to re2c consists of C/C++ source
re2c: interleaved with comments of the form /*!re2c ... */ which contain
re2c: scanner specifications. In the output these comments are replaced
re2c: with code that, when executed, will find the next input token and
re2c: then execute some user-supplied token-specific code.
re2c:
re2c:
re2c:" >$PKG/install/slack-desc

# build script
cp $CWD/build-$NAME.sh $PKG/usr/src/$PKGNAME

find $PKG/usr/doc -type f |xargs chmod u+w,go=r
cd $PKG
fakeroot /sbin/makepkg -l y -c n $CWD/$PACKAGE.tgz

cd $CWD
md5sum $PACKAGE.tgz > $PACKAGE.md5

echo "http://users.zenwalk.org/user-accounts/tilderb/extra/re2c/build-re2c.sh
$SOURCE" >$PACKAGE.src

